package App::skos2jskos;
use v5.14;

our $VERSION = '0.2.1';

1;

=head1 NAME

App::skos2jskos - Convert SKOS/RDF to JSKOS format

=head1 DESCRIPTION

See L<skos2jskos> command line script.

=head1 INSTALLATION

  cpanm App::skos2jskos

To speed up installation, install required Perl modules as system packages, e.g.

  sudo apt-get install librdf-query-perl librdf-query-client-perl

=head1 AUTHOR

Jakob Voss <voss@gbv.de>

=head1 COPYRIGHT AND LICENSE

Copyright Jakob Voss, 2015-

GPL 2.0

=cut
